CCA
===

.. currentmodule:: xeofs.multi

.. autoclass:: CCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CCA.__init__
      ~CCA.components
      ~CCA.explained_covariance
      ~CCA.explained_covariance_ratio
      ~CCA.explained_variance
      ~CCA.explained_variance_ratio
      ~CCA.fit
      ~CCA.get_metadata_routing
      ~CCA.get_params
      ~CCA.scores
      ~CCA.set_fit_request
      ~CCA.set_params
      ~CCA.set_transform_request
      ~CCA.transform
      ~CCA.weights
   
   

   
   
   